@@ -157,7 +157,7 @@
 	mRegressCovar<-StS/n
     
 	if(is.element("tree_height",names(phyltree))){StS<-StS/phyltree$tree_height}else{StS<-StS/(log(n))}
-	Sxx<-t(chol(StS))
+	Sxx<-t(.my_chol(StS))
 
 	## Brownian motion with drift can also be considered here
 	## model was originally setup as OU now 'dropped' to BM
@@ -203,7 +203,7 @@
 		StS<-as.matrix(Matrix::nearPD(StS)$mat)
 	    }
 
-	    Sxx<-t(chol(StS))
+	    Sxx<-t(.my_chol(StS))
 	    StS[which(abs(StS)<1e-15)]<-0
     	    Sxx[which(abs(Sxx)<1e-15)]<-0
 	    
